==> AttachmentField-1.3.7.tgz: AttachmentField/skins/attachmentfield/attachment_download.py <==
##parameters=

NotFound = "NotFound"
request = context.REQUEST
response = request.RESPONSE

if len(traverse_subpath) != 1:
    raise NotFound, "Unknown page."

name = traverse_subpath[0]
field = context.getField(name)

if not field:
    raise NotFound, "Unknown page."
elif hasattr(field, 'getFields'):
    index = int(request.form.get(name))
    field = field.getFields()[index + 1]

accessor = field.getAccessor(context)

if accessor is None:
    raise NotFound, "Unknown page."

obj = accessor()

if hasattr(obj.aq_explicit, 'download'):
    return obj.download(request)
else:
    data = ''
    filename = ''
    content_type = 'application/octet-stream'
    size = 0

    if hasattr(obj.aq_explicit, 'data'):
        # handle OFS.Image.File and OFS.Image.Image
        data = str(obj.data)
        filename = obj.title
        content_type = obj.getContentType()
        size = obj.get_size()
    else:
        data = str(obj)
        size = len(data)

    attachmentTool = context.portal_attachment
    widget = field.widget
    if hasattr(widget, "contentDisposition"):
        if widget.contentDisposition in attachmentTool.getAvailableContentDisposition():
            ## disposition is defined by widget
            disposition = widget.contentDisposition
        else:
            raise ValueError(
                "contentDisposition %s is not in %s." % (
                    widget.contentDisposition, attachmentTool.getAvailableContentDisposition()
                )
            )
    else:
        ## default site wide choice

        disposition = attachmentTool.getContentDisposition()

    response.setHeader(
        'Content-Disposition',
        '%s; filename="%s"' % (disposition, filename)
    )
    response.setHeader('Content-Type', content_type)
    response.setHeader('Content-Length', size)
    response.write(data)

==> AttachmentField-1.3.9.tgz: AttachmentField/skins/attachmentfield/attachment_download.py <==
##parameters=

NotFound = "NotFound"
request = context.REQUEST
response = request.RESPONSE

if len(traverse_subpath) != 1:
    raise NotFound, "Unknown page."

name = traverse_subpath[0]
field = context.getField(name)

if not field:
    raise NotFound, "Unknown page."
elif hasattr(field, 'getFields'):
    index = int(request.form.get(name))
    field = field.getFields()[index + 1]

accessor = field.getAccessor(context)

if accessor is None:
    raise NotFound, "Unknown page."

obj = accessor()

attachmentTool = context.portal_attachment
widget = field.widget
if hasattr(widget, "contentDisposition"):
    if widget.contentDisposition in attachmentTool.getAvailableContentDisposition():
        ## disposition is defined by widget
        disposition = widget.contentDisposition
    else:
        raise ValueError(
            "contentDisposition %s is not in %s." % (
                widget.contentDisposition, attachmentTool.getAvailableContentDisposition()
            )
        )
else:
    ## default site wide choice
    disposition = attachmentTool.getContentDisposition()


if hasattr(obj.aq_explicit, 'download'):
    # FSS hack -> return a stream iterator to avoid loading the full file in memory
    return obj.download(request, disposition)
else:
    data = ''
    filename = ''
    content_type = 'application/octet-stream'
    size = 0

    if hasattr(obj.aq_explicit, 'data'):
        # handle OFS.Image.File and OFS.Image.Image
        data = str(obj.data)
        filename = obj.title
        content_type = obj.getContentType()
        size = obj.get_size()
    else:
        data = str(obj)
        size = len(data)

    response.setHeader(
        'Content-Disposition',
        '%s; filename="%s"' % (disposition, filename)
    )
    response.setHeader('Content-Type', content_type)
    response.setHeader('Content-Length', size)
    response.write(data)
